@@ -21,6 +21,7 @@
 import copy
 from typing import TYPE_CHECKING, Dict, List, Optional, TypeVar, Union
 
+from appium.common.logger import logger
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
 if TYPE_CHECKING:
@@ -32,7 +33,14 @@ T = TypeVar('T', bound='MultiAction')
 
 
 class MultiAction:
+    """
+    Deprecated.
+    Please use W3C actions instead: http://appium.io/docs/en/commands/interactions/actions/
+    """
+
     def __init__(self, driver: 'WebDriver', element: Optional['WebElement'] = None) -> None:
+        logger.warning("[Deprecated] 'MultiAction' action is deprecated. Please use W3C actions instead.")
+
         self._driver = driver
         self._element = element
         self._touch_actions: List['TouchAction'] = []
