@@ -14,43 +14,53 @@
 
 # pylint: disable=abstract-method
 
+from typing import TYPE_CHECKING, List, TypeVar, Union
+
+from appium.common.logger import logger
 from appium.webdriver.common.mobileby import MobileBy
 
 from .base_search_context import BaseSearchContext
 
+if TYPE_CHECKING:
+    from appium.webdriver.webelement import WebElement
+
+T = TypeVar('T', bound=Union[BaseSearchContext, 'WindowsSearchContext'])
+
 
 class WindowsSearchContext(BaseSearchContext):
     """Define search context for Windows"""
 
-    def find_element_by_windows_uiautomation(self, win_uiautomation):
-        """Finds an element by windows uiautomation
+    def find_element_by_windows_uiautomation(self: T, win_uiautomation: str) -> 'WebElement':
+        """[Deprecated] Finds an element by windows uiautomation
 
         Args:
-            win_uiautomation (str): The element name in the windows UIAutomation selector
+            win_uiautomation: The element name in the windows UIAutomation selector
 
         Usage:
             driver.find_element_by_windows_uiautomation()
 
         Returns:
-            `appium.webdriver.webelement.WebElement`
+            `appium.webdriver.webelement.WebElement`: The found element
 
-        # To enable auto completion in PyCharm(IDE)
-        :rtype: `appium.webdriver.webelement.WebElement`
         """
+        logger.warning(
+            "[Deprecated] '-windows uiautomation' selector is deprecated. Please use other locators like id."
+        )
         return self.find_element(by=MobileBy.WINDOWS_UI_AUTOMATION, value=win_uiautomation)
 
-    def find_elements_by_windows_uiautomation(self, win_uiautomation):
-        """Finds elements by windows uiautomation
+    def find_elements_by_windows_uiautomation(self: T, win_uiautomation: str) -> List['WebElement']:
+        """[Deprecated] Finds elements by windows uiautomation
 
         Args:
-            win_uiautomation (str): The element name in the windows UIAutomation selector
+            win_uiautomation: The element name in the windows UIAutomation selector
 
         Usage:
             driver.find_elements_by_windows_uiautomation()
 
         Returns:
-            :obj:`list` of :obj:`appium.webdriver.webelement.WebElement`
-
-        :rtype: list of `appium.webdriver.webelement.WebElement`
+            :obj:`list` of :obj:`appium.webdriver.webelement.WebElement`: The found elements
         """
+        logger.warning(
+            "[Deprecated] '-windows uiautomation' selector is deprecated. Please use other locators like id."
+        )
         return self.find_elements(by=MobileBy.WINDOWS_UI_AUTOMATION, value=win_uiautomation)
